@@ -21,22 +21,30 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from abc import ABCMeta, abstractmethod
+from abc import ABCMeta, abstractmethod, abstractproperty
 
 from pyrogram import KeyboardButton
 from pyrogram.client.filters.filter import Filter
 
 
 class Button:
-    __meta__ = ABCMeta
+    __metaclass__ = ABCMeta
 
     @abstractmethod
+    def __hash__(self) -> int:
+        ...
+
+    @abstractmethod
+    def __eq__(self, other_button: "Button") -> bool:
+        ...
+
+    @abstractproperty
     def keyboard_button(self) -> KeyboardButton:
-        pass
+        ...
 
-    @abstractmethod
+    @abstractproperty
     def update_filter(self) -> Filter:
-        pass
+        ...
 
 
 __all__ = ["Button"]
