@@ -21,19 +21,32 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from abc import ABCMeta, abstractmethod
+from abc import ABCMeta, abstractproperty, abstractmethod
 
-from pyrogram import ReplyKeyboardMarkup
+from pyrogram import ReplyKeyboardMarkup, Message
 from pyrogram.client.filters.filter import Filter
 
+from pyromenu.abc import Button
+
 
 class Menu:
-    __meta__ = ABCMeta
+    __metaclass__ = ABCMeta
 
-    @abstractmethod
+    @abstractproperty
     def keyboard(self) -> ReplyKeyboardMarkup:
-        pass
+        ...
+
+    @abstractproperty
+    def one_time_keyboard(self) -> ReplyKeyboardMarkup:
+        ...
+
+    @abstractproperty
+    def filter(self) -> Filter:
+        ...
 
     @abstractmethod
-    def one_time_keyboard(self) -> ReplyKeyboardMarkup:
-        pass
+    def matched_button(self, msg: Message) -> Button:
+        ...
+
+
+__all__ = ["Menu"]
