@@ -21,19 +21,25 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from abc import ABCMeta, abstractmethod
+from abc import ABCMeta, abstractproperty
 from typing import List
 
 from pyrogram import KeyboardButton
 from pyrogram.client.filters.filter import Filter
 
+from .button import Button
+
 
 class Row:
-    __meta__ = ABCMeta
+    __metaclass__ = ABCMeta
 
-    @abstractmethod
+    @abstractproperty
     def keyboard_row(self) -> List[KeyboardButton]:
-        pass
+        ...
+
+    @abstractproperty
+    def buttons(self) -> List[Button]:
+        ...
 
 
 __all__ = ["Row"]
